@@ -1,3 +1,4 @@
+/* $Id: gucharmap-charmap.c 1386 2007-12-04 22:11:19Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -13,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
 #include "config.h"
@@ -29,6 +30,7 @@
 #include "gucharmap-intl.h"
 #include "gucharmap-marshal.h"
 #include "gucharmap-settings.h"
+#include "chartable_accessible.h"
 
 gboolean _gucharmap_unicode_has_nameslist_entry (gunichar uc);
 
@@ -66,7 +68,7 @@ gucharmap_charmap_class_init (GucharmapCharmapClass *clazz)
       g_signal_new ("status-message", gucharmap_charmap_get_type (), 
                     G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapCharmapClass, status_message),
-                    NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE,
+                    NULL, NULL, _gucharmap_marshal_VOID__STRING, G_TYPE_NONE, 
                     1, G_TYPE_STRING);
 
   gucharmap_charmap_signals[LINK_CLICKED] =
@@ -296,7 +298,7 @@ set_details (GucharmapCharmap *charmap,
   gunichar2 *utf16;
 
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (charmap->details));
-  gtk_text_buffer_set_text (buffer, "", 0);
+  gtk_text_buffer_set_text (buffer, "", -1);
 
   gtk_text_buffer_get_start_iter (buffer, &iter);
   gtk_text_buffer_place_cursor (buffer, &iter);
@@ -497,8 +499,7 @@ active_char_set (GtkWidget        *widget,
   const gchar **temps;
   gint i;
 
-  if (charmap->showing_details_page)
-    set_details (charmap, wc);
+  set_details (charmap, wc);
 
   g_idle_add (gucharmap_active_char_save, GUINT_TO_POINTER(wc));
 
@@ -766,27 +767,8 @@ make_details_page (GucharmapCharmap *charmap)
   return scrolled_window;
 }
 
-static void
-notebook_switch_page (GtkNotebook *notebook,
-                      GtkNotebookPage *page /* useless */,
-                      guint page_num,
-                      GucharmapCharmap *charmap)
-{
-  charmap->showing_details_page = (page_num == 1);
-
-  if (charmap->showing_details_page)
-    set_details (charmap, gucharmap_table_get_active_character (charmap->chartable));
-  else
-    {
-      GtkTextBuffer *buffer;
-
-      buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (charmap->details));
-      gtk_text_buffer_set_text (buffer, "", 0);
-    }
-}
-
 static GtkWidget *
-make_chartable_pane (GucharmapCharmap *charmap)
+make_chartable_pane (GucharmapCharmap       *charmap)
 {
   GtkWidget *notebook;
 
@@ -839,8 +821,6 @@ gucharmap_charmap_new (GucharmapChapters *chapters)
   pane2 = make_chartable_pane (charmap);
   gtk_paned_pack1 (GTK_PANED (charmap), GTK_WIDGET (chapters), FALSE, TRUE);
   gtk_paned_pack2 (GTK_PANED (charmap), pane2, TRUE, TRUE);
-  g_signal_connect (pane2, "switch-page",
-                    G_CALLBACK (notebook_switch_page), charmap);
 
   gucharmap_charmap_go_to_character (charmap, gucharmap_settings_get_last_char ());
 
